// node modules
import React, {FC, useState, useEffect, ReactElement} from 'react';

// local components
import { SimpleButton } from "../buttons/simple_button";
import { Typography } from "../typography";

// local files
import { uniqIdGenerator } from "../../utils/local_utils";
import { theming } from "../../theme";
import { useStyles } from "./styles";

type item = {
    title: string;
    Content: FC<any>,
}

export interface TabProps {
    list: item[],
    activeTab: number,
    width?: string | number,
    contentClass?: string;
    tabWrapperClass?: string;
    tabClass?: string;
    onChange?: (index: number) => any,
    children: ReactElement<any>
}

export const Tab: FC<TabProps> = ({
    list,
    activeTab = 0,
    width = '100%',
    contentClass = '',
    tabWrapperClass = '',
    tabClass = '',
    onChange,
    children
}) => {
    const { tabWrapper, activeBtn, btn, wrapper } = useStyles({ theme: theming.useTheme() })
    const [currentTab, setCurrentTab] = useState(activeTab);
    const { Content } = list[currentTab];

    useEffect(() => {
        setCurrentTab(activeTab)
        if (onChange) onChange(activeTab)
    }, [activeTab])

    return (
        <div className={wrapper} style={{ width }}>
            <div className={`${tabWrapper} ${tabWrapperClass}`}>
                {list.map(({ title }, i) => {
                    const className = `${i === currentTab ? activeBtn : ''} ${btn} ${tabClass}`

                    return (
                        <SimpleButton
                            key={uniqIdGenerator()}
                            className={className}
                            width={`calc(100% / ${list.length} )`}
                            onClick={() => setCurrentTab(i)}
                            label={
                                <Typography variant="label">
                                    {title}
                                </Typography>
                            }
                        />
                    )})}
            </div>
            <div className={contentClass}>
                {children ? children : (<Content />)}
            </div>
        </div>
    )
};
